<?php

namespace Elementor;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;

if (!defined('ABSPATH')) exit;

class Price extends Widget_Base
{
    public function get_name()
    {
        return 'price';
    }

    public function get_title()
    {
        return esc_html__('Price Item', 'conbix-toolkit');
    }

    public function get_icon()
    {
        return 'eicon-gallery-grid';
    }

    public function get_categories()
    {
        return ['conbix-toolkit'];
    }

    public function get_keywords()
    {
        return ['Conbix', 'Toolkit', 'price', 'table'];
    }

    protected function register_controls()

    {

        $this->start_controls_section(
            'section_general',
            [
                'label' => esc_html__('Style & Design', 'conbix-toolkit'),
            ]
        );

        $this->add_control(
            'select_design',
            [
                'label'   => esc_html__('Select a Style', 'conbix-toolkit'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'design-1' => esc_html__('Design 01', 'conbix-toolkit'),
                    'design-2' => esc_html__('Design 02', 'conbix-toolkit'),
                ],
                'default'      => 'design-1',
                'label_block'  => true,
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Section Content', 'conbix-toolkit'),
            ]
        );

        $this->add_control(
            'sub_title',
            [
                'label' => esc_html__('Sub Title', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Start package', 'conbix-toolkit'),
                'label_block' => true,
                'condition' => [
                    'select_design' => ['design-1'],
                ],
            ]
        );


        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Basic Plan', 'conbix-toolkit'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'period',
            [
                'label' => esc_html__('Period', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Monthly', 'conbix-toolkit'),
                'label_block' => true,
                'condition' => [
                    'select_design' => ['design-1'],
                ],
            ]
        );

        $this->add_control(
            'price',
            [
                'label' => esc_html__('Price', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('$29', 'conbix-toolkit'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label' => esc_html__('Button Text', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'conbix-toolkit'),
                'label_block' => true,
                'condition' => [
                    'select_design!' => ['design-3'],
                ],
            ]
        );

        $this->add_control(
            'btn_url',
            [
                'label' => esc_html__('Button URL', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_attr__('http://google.com', 'conbix-toolkit'),
                'condition' => [
                    'select_design!' => ['design-3'],
                ],
            ]
        );


        $priceitem = new Repeater();

        $priceitem->add_control(
            'item_icon',
            [
                'label' => esc_html__('Icon', 'conbix-toolkit'),
                'type' => Controls_Manager::ICONS,
                'label_block' => true,
                'default' => [
                    'value' => 'fa fa-check',
                    'library' => 'regular',
                ],
            ]
        );

        $priceitem->add_control(
            'item_title',
            [
                'label' => esc_html__('Item Name', 'conbix-toolkit'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'Item_list',
            [
                'label' => esc_html__('Price Item List', 'conbix-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $priceitem->get_controls(),
                'default' => [
                    [
                        'item_title' => esc_html__('Business Planning', 'conbix-toolkit'),

                    ],
                    [
                        'item_title' => esc_html__('24/7 Customer Support', 'conbix-toolkit'),

                    ],
                ],
                'title_field' => '{{{ item_title }}}',
            ]
        );


        $this->end_controls_section();
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $conbix_htmls = array(
            'span'   => array(),
        );
?>
        <?php if ('design-1' === $settings['select_design']) : ?>
            <div class="pricing__area-item">
                <div class="pricing__area-item-price">
                    <h4><?php echo wp_kses($settings['price'], $conbix_htmls); ?></h4>
                    <span class="text-two"><?php echo esc_html($settings['period']); ?></span>
                </div>
                <div class="pricing__area-item-title">
                    <span class="text-two"><?php echo esc_html($settings['sub_title']); ?></span>
                    <h3><?php echo esc_html($settings['title']); ?></h3>
                </div>
                <div class="pricing__area-item-list">
                    <ul>
                        <?php foreach ($settings['Item_list'] as $item) : ?>
                            <li><i class="<?php echo esc_attr($item['item_icon']['value']); ?>"></i><?php echo esc_html($item['item_title']); ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
                <?php if (!empty($settings['btn_url'])) : ?>
                    <a class="btn-eight" href="<?php echo esc_url($settings['btn_url']); ?>"><?php echo esc_html($settings['btn_text']); ?></a>
                <?php endif; ?>
            </div>
        <?php endif; ?>

        <?php if ('design-2' === $settings['select_design']) : ?>
            <div class="pricing__two-item">
                <div class="pricing__two-item-price">
                    <span><?php echo esc_html($settings['title']); ?></span>
                    <h2><?php echo wp_kses($settings['price'], $conbix_htmls); ?></span></h2>
                </div>
                <div class="pricing__two-item-list">
                    <ul>
                        <?php foreach ($settings['Item_list'] as $item) : ?>
                            <li><i class="<?php echo esc_attr($item['item_icon']['value']); ?>"></i><?php echo esc_html($item['item_title']); ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
                <?php if (!empty($settings['btn_url'])) : ?>
                    <div class="pricing__two-item-btn">
                        <a class="btn-three" href="<?php echo esc_url($settings['btn_url']); ?>"><?php echo esc_html($settings['btn_text']); ?></a>
                    </div>
                <?php endif; ?>
            </div>
        <?php endif; ?>

<?php
    }
}

Plugin::instance()->widgets_manager->register(new Price);
